@@ -53,5 +53,13 @@ typedef CTX* Fl__SecretInput;
 typedef CTX* Fl__ToggleButton;
 typedef CTX* Fl__Valuator;
 typedef CTX* Fl__Adjuster;
+typedef CTX* Fl__Counter;
+typedef CTX* Fl__SimpleCounter;
+typedef CTX* Fl__Dial;
+typedef CTX* Fl__FillDial;
+typedef CTX* Fl__LineDial;
+typedef CTX* Fl__Roller;
+typedef CTX* Fl__ValueOutput;
+typedef CTX* Fl__ValueInput;
 
 #endif // #ifndef fltk_pm_h
